==> jena-arq-2.9.2-sources.jar: org/openjena/riot/out/NQuadsWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.openjena.riot.out;

import java.io.OutputStream ;
import java.util.Iterator ;

import org.openjena.atlas.iterator.Iter ;
import org.openjena.atlas.lib.Sink ;
import org.openjena.riot.system.Prologue ;
import org.openjena.riot.system.SyntaxLabels ;

import com.hp.hpl.jena.graph.Node ;
import com.hp.hpl.jena.sparql.core.DatasetGraph ;
import com.hp.hpl.jena.sparql.core.Quad ;

public class NQuadsWriter
{
    public static void write(OutputStream out, DatasetGraph dsg)
    {
        write(out, dsg.find(Node.ANY, Node.ANY, Node.ANY, Node.ANY)) ;
    }
    
    public static void write(OutputStream out, Iterator<Quad> iter)
    {
        Prologue prologue = Prologue.create(null, null) ; // (null, graph.getPrefixMapping()) ;
        // Write prologue.
        Sink<Quad> sink = new SinkQuadOutput(out, prologue, SyntaxLabels.createNodeToLabel()) ;
        Iter.sendToSink(iter, sink) ;
    }
}

==> jena-arq-2.9.4-sources.jar: org/openjena/riot/out/NQuadsWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.openjena.riot.out;

import java.io.OutputStream ;
import java.util.Iterator ;

import org.openjena.atlas.iterator.Iter ;
import org.openjena.atlas.lib.Sink ;
import org.openjena.riot.system.Prologue ;
import org.openjena.riot.system.SyntaxLabels ;

import com.hp.hpl.jena.graph.Node ;
import com.hp.hpl.jena.query.Dataset ;
import com.hp.hpl.jena.sparql.core.DatasetGraph ;
import com.hp.hpl.jena.sparql.core.Quad ;

public class NQuadsWriter
{
    public static void write(OutputStream out, DatasetGraph dsg)
    {
        write(out, dsg.find(Node.ANY, Node.ANY, Node.ANY, Node.ANY)) ;
    }
    
    public static void write(OutputStream out, Dataset dsg)
    {
        write(out, dsg.asDatasetGraph()) ;
    }
    
    public static void write(OutputStream out, Iterator<Quad> iter)
    {
        Prologue prologue = Prologue.create(null, null) ; // (null, graph.getPrefixMapping()) ;
        // Write prologue.
        Sink<Quad> sink = new SinkQuadOutput(out, prologue, SyntaxLabels.createNodeToLabel()) ;
        Iter.sendToSink(iter, sink) ;
    }
}
